@@ -33,23 +33,23 @@
 #include <QPainter>
 #include <QDir>
 
-#include <kselectaction.h>
-#include <ktoggleaction.h>
-#include <kactioncollection.h>
-#include <kconfigdialog.h>
-#include <kdebug.h>
-#include <kfiledialog.h>
-#include <klineedit.h>
+#include <KSelectAction>
+#include <KToggleAction>
+#include <KActionCollection>
+#include <KConfigDialog>
+#include <KDebug>
+#include <KFileDialog>
+#include <KLineEdit>
 #include <KLocale>
-#include <kxmlguiwindow.h>
-#include <kmessagebox.h>
-#include <kstandardaction.h>
-#include <kstandarddirs.h>
-#include <kstatusbar.h>
-#include <ktoolbar.h>
-#include <kicon.h>
-#include <kglobal.h>
+#include <KMessageBox>
+#include <KStandardAction>
+#include <KStandardDirs>
+#include <KStatusBar>
+#include <KToolBar>
+#include <KIcon>
+#include <KGlobal>
 #include <KSharedConfig>
+
 #include <knewstuff2/engine.h>
 
 KHangMan::KHangMan()
@@ -101,7 +101,7 @@ void KHangMan::setupActions()
     hintAct->setIcon(KIcon("games-hint"));
     hintAct->setShortcut(QKeySequence(Qt::CTRL+Qt::Key_H));
     hintAct->setEnabled( m_view->hintExists() );
-    connect(hintAct, SIGNAL(triggered(bool)), this, SLOT(slotChangeHintAction(bool)));
+    connect(hintAct, SIGNAL(triggered(bool)), this, SLOT(slotSetHint(bool)));
     // Game->Get Words in New Language
     KAction *newStuffAct  = new KAction(i18n("&Get Words in New Language..."), this);
     actionCollection()->addAction("downloadnewstuff", newStuffAct );
@@ -144,7 +144,6 @@ void KHangMan::setupActions()
 void KHangMan::setupStatusbar()
 {
     // set up the status bar
-    statusBar()->insertPermanentItem("   ", IDS_LANG,    0);
     statusBar()->insertPermanentItem("   ", IDS_LEVEL,   0);
     statusBar()->insertPermanentItem("   ", IDS_ACCENTS, 0);
     statusBar()->insertItem("   ", IDS_WINS,    1);
@@ -188,7 +187,6 @@ void KHangMan::slotChangeLanguage(int index)
     Prefs::self()->writeConfig();
     loadLevels();
     loadLangToolBar();
-    changeStatusbar(m_languageNames[m_languages.indexOf(Prefs::selectedLanguage())], IDS_LANG);
     setAccent();
     setMessages();
     m_view->newGame();
@@ -237,7 +235,7 @@ void KHangMan::setLanguages()
         KConfigGroup group = entry.group(m_languages[i]);
         QString languageName = group.readEntry("Name");
         if (languageName.isEmpty()) {
-            languageName = i18n("None");
+            languageName = i18nc("@item:inlistbox no language for that locale","None");
         }
         m_languageNames.append(languageName);
     }
@@ -259,7 +257,6 @@ void KHangMan::loadSettings()
         // if the selected language is not available, use the first available one
         index = 0;
     }
-    changeStatusbar(m_languageNames[index], IDS_LANG);
     // Show/hide characters toolbar
     if (Prefs::showCharToolbar()) {
         specialCharToolbar->show();
@@ -363,8 +360,10 @@ void KHangMan::updateSettings()
     if (Prefs::selectedLanguage() == "de") {
         loadLangToolBar();
     }
+    hintAct->setChecked(Prefs::hint());
 
     setMessages();
+    //m_view->newGame();
 }
 
 void KHangMan::slotDownloadNewStuff()
@@ -538,22 +537,24 @@ void KHangMan::slotFileOpen()
 {
     KUrl url = KFileDialog::getOpenUrl(QString(), KEduVocDocument::pattern(KEduVocDocument::Reading), this, i18n("Open Vocabulary Document"));
     if ( url.isValid() )  {
-        Prefs::setLevelFile(url.path());
+        if(url.isLocalFile())
+            Prefs::setLevelFile(url.toLocalFile());
+        else
+            Prefs::setLevelFile(url.path());
         Prefs::self()->writeConfig();
         changeStatusbar(url.path().section('/', -1), IDS_LEVEL);
-        changeStatusbar(i18n("Local file"), IDS_LANG);
         m_view->readFile();
         m_view->newGame();
     }
 }
 
-void KHangMan::slotChangeHintAction(bool hint)
+void KHangMan::slotSetHint(bool hint)
 {
     Prefs::setHint(hint);
     Prefs::self()->writeConfig();
     m_view->update();
-
 }
+
 #include "khangman.moc"
 
 // kate: space-indent on; tab-width 4; indent-width 4; mixed-indent off; replace-tabs on;
