@@ -26,15 +26,11 @@
 
 void dms::setD( const double &x ) {
     D = x;
-    scDirty = true;
-    rDirty = true;
 }
 
 void dms::setD(const int &d, const int &m, const int &s, const int &ms) {
     D = (double)abs(d) + ((double)m + ((double)s + (double)ms/1000.)/60.)/60.;
     if (d<0) {D = -1.0*D;}
-    scDirty = true;
-    rDirty = true;
 }
 
 void dms::setH( const double &x ) {
@@ -44,15 +40,10 @@ void dms::setH( const double &x ) {
 void dms::setH(const int &h, const int &m, const int &s, const int &ms) {
     D = 15.0*((double)abs(h) + ((double)m + ((double)s + (double)ms/1000.)/60.)/60.);
     if (h<0) {D = -1.0*D;}
-    scDirty = true;
-    rDirty = true;
 }
 
 void dms::setRadians( const double &Rad ) {
     setD( Rad/DegToRad );
-    Radians = Rad;
-    scDirty = true;
-    rDirty = true;
 }
 
 bool dms::setFromString( const QString &str, bool isDeg ) {
@@ -208,60 +199,6 @@ int dms::msecond( void ) const {
     return hs;
 }
 
-const double& dms::sin( void ) const {
-    if ( scDirty ) {
-        double s,c;
-        SinCos( s, c );
-    }
-
-    return Sin;
-}
-
-const double& dms::cos( void ) const {
-    if ( scDirty ) {
-        double s,c;
-        SinCos( s, c );
-    }
-
-    return Cos;
-}
-
-void dms::SinCos( double &sina, double &cosa ) const {
-    /**We have two versions of this function.  One is ANSI standard, but
-    	*slower.  The other is faster, but is GNU only.
-    	*Using the __GLIBC_ and __GLIBC_MINOR_ constants to determine if the
-    	* GNU extension sincos() is defined.
-    	*/
-
-    if ( scDirty ) {
-                #ifdef __GLIBC__
-                #if ( __GLIBC__ >= 2 && __GLIBC_MINOR__ >=1 && !defined(__UCLIBC__))
-        //GNU version
-        sincos( radians(), &Sin, &Cos );
-                #else
-        //For older GLIBC versions
-        Sin = ::sin( radians() );
-        Cos = ::cos( radians() );
-		#endif
-		#else
-        //ANSI-compliant version
-        Sin = ::sin( radians() );
-        Cos = ::cos( radians() );
-		#endif
-        scDirty = false;
-    }
-    sina = Sin;
-    cosa = Cos;
-}
-
-const double& dms::radians( void ) const {
-    if ( rDirty ) {
-        Radians = D*DegToRad;
-        rDirty = false;
-    }
-
-    return Radians;
-}
 
 const dms dms::reduce( void ) const {
     double a = D;
