@@ -44,7 +44,7 @@ FlagComponent::~FlagComponent()
 {
 }
 
-void FlagComponent::init( KStarsData *data ) {
+void FlagComponent::init() {
     KSFileReader fileReader;
     QStringList line;
     QString str;
@@ -54,7 +54,7 @@ void FlagComponent::init( KStarsData *data ) {
     // Return if flags.dat does not exist
     if ( ! QFile::exists ( KStandardDirs::locateLocal( "appdata", "flags.dat" ) ) ) return;
 
-    // Return if flags.dat cna not be read
+    // Return if flags.dat can not be read
     if ( ! fileReader.open( "flags.dat" ) ) return;
 
     // Read flags.dat
@@ -90,11 +90,24 @@ void FlagComponent::init( KStarsData *data ) {
 
         imageFound = false;
 
-        // Continue if there is no label
-        if ( ! ( line.size() > 4 ) )
+        // If there is no label, use an empty string, red color and continue.
+        if ( ! ( line.size() > 4 ) ) {
+            m_Labels.append( "" );
+            m_LabelColors.append( QColor( "red" ) );
             continue;
+        }
+
+        // Read label and color label
+        // If the last word is a color value, use it to set label color
+        // Else use red
+        QRegExp rxLabelColor( "^#[a-fA-F0-9]{6}$" );
+        if ( rxLabelColor.exactMatch( line.last() ) ) {
+            m_LabelColors.append( QColor( line.last() ) );
+            line.removeLast();
+        } else {
+            m_LabelColors.append( QColor( "red" ) );
+        }
 
-        // Read label
         str.clear();
         for ( i=4; i<line.size(); ++i ) {
             str += line.at( i ) + ' ';
@@ -137,7 +150,7 @@ void FlagComponent::draw( QPainter& psky )
         o.setX( o.x() + 25.0 );
         o.setY( o.y() + 12.0 );
         psky.save();
-        psky.setPen( QColor( 255, 0, 0 ) );
+        psky.setPen( m_LabelColors.at( i ) );
         psky.setFont( QFont( "Courier New", 10, QFont::Bold ) );
         psky.drawText( o, m_Labels.at( i ) );
         psky.restore();
@@ -173,7 +186,7 @@ long double FlagComponent::epochToJd (double epoch) {
 
 }
 
-void FlagComponent::add( SkyPoint* flagPoint, QString epoch, QString image, QString label ) {
+void FlagComponent::add( SkyPoint* flagPoint, QString epoch, QString image, QString label, QColor labelColor ) {
     int i;
 
     pointList().append( flagPoint );
@@ -186,6 +199,7 @@ void FlagComponent::add( SkyPoint* flagPoint, QString epoch, QString image, QStr
     }
 
     m_Labels.append( label );
+    m_LabelColors.append( labelColor );
 }
 
 void FlagComponent::remove( int index ) {
@@ -193,6 +207,7 @@ void FlagComponent::remove( int index ) {
     m_Epoch.removeAt( index );
     m_FlagImages.removeAt( index );
     m_Labels.removeAt( index );
+    m_LabelColors.removeAt( index );
 }
 
 void FlagComponent::slotLoadImages( KIO::Job* job, const KIO::UDSEntryList& list ) {
@@ -201,7 +216,7 @@ void FlagComponent::slotLoadImages( KIO::Job* job, const KIO::UDSEntryList& list
     QStringList fileNameLst;
     QImage flagImage;
 
-    m_Names.append( i18n( "Default" ) );
+    m_Names.append( i18n ("Default" ) );
     flagImage.load( KStandardDirs::locate( "appdata", "defaultflag.gif" ) );
     m_Images.append( flagImage );
 
@@ -239,6 +254,10 @@ QString FlagComponent::label( int index ) {
     return m_Labels.at( index );
 }
 
+QColor FlagComponent::labelColor( int index ) {
+    return m_LabelColors.at( index );
+}
+
 QImage FlagComponent::image( int index ) {
     return m_Images.at( m_FlagImages.at( index ) );
 }
