@@ -29,6 +29,32 @@
 #include "kssun.h"
 #include "kstarsdata.h"
 
+namespace {
+    // Convert degrees to radians and put it into [0,2*pi] range
+    double degToRad(double x) {
+        return dms::DegToRad * KSUtils::reduceAngle(x, 0.0, 360.0);
+    }
+
+    /*
+     * Data used to calculate moon magnitude. 
+     *
+     * Formula and data were obtained from SkyChart v3.x Beta
+     *
+     */
+    // intensities in Table 1 of M. Minnaert (1961),
+    // Phase  Frac.            Phase  Frac.            Phase  Frac.
+    // angle  ill.   Mag       angle  ill.   Mag       angle  ill.   Mag
+    //  0    1.00  -12.7        60   0.75  -11.0       120   0.25  -8.7
+    // 10    0.99  -12.4        70   0.67  -10.8       130   0.18  -8.2
+    // 20    0.97  -12.1        80   0.59  -10.4       140   0.12  -7.6
+    // 30    0.93  -11.8        90   0.50  -10.0       150   0.07  -6.7
+    // 40    0.88  -11.5       100   0.41   -9.6       160   0.03  -3.4
+    // 50    0.82  -11.2       110   0.33   -9.2
+    static const double MagArray[19] = {
+        -12.7, -12.4, -12.1, -11.8, -11.5, -11.2, -11.0, -10.8, -10.4, -10.0,
+        -9.6,  -9.2,  -8.7,  -8.2,  -7.6,  -6.7,  -3.4,  0, 0};
+}
+
 KSMoon::KSMoon()
         : KSPlanetBase( I18N_NOOP( "Moon" ), QString(), QColor("white"), 3474.8 /*diameter in km*/ )
 {
@@ -51,29 +77,24 @@ KSMoon* KSMoon::clone() const
 KSMoon::~KSMoon() {
     instance_count--;
     if(instance_count <= 0) {
-        while ( ! LRData.isEmpty() ) delete LRData.takeFirst();
-        while ( !  BData.isEmpty() ) delete  BData.takeFirst();
-	data_loaded = false;
+        LRData.clear();
+        BData.clear();
+        data_loaded = false;
     }
 }
 
 bool KSMoon::data_loaded = false;
 int KSMoon::instance_count = 0;
-QList<KSMoon::MoonLRData*> KSMoon::LRData;
-QList<KSMoon::MoonBData*> KSMoon::BData;
-
-const double KSMoon::MagArray[19] = {-12.7,-12.4,-12.1,-11.8,-11.5,-11.2,
-                               -11.0,-10.8,-10.4,-10.0,-9.6,-9.2,
-                               -8.7,-8.2,-7.6,-6.7,-3.4,0,0};
+QList<KSMoon::MoonLRData> KSMoon::LRData;
+QList<KSMoon::MoonBData> KSMoon::BData;
 
 
 bool KSMoon::loadData() {
-    if (data_loaded) return true;
+    if (data_loaded)
+        return true;
 
     QStringList fields;
     QFile f;
-    int nd, nm, nm1, nf;
-    double Li, Ri, Bi; //coefficients of the sums
 
     if ( KSUtils::openDataFile( f, "moonLR.dat" ) ) {
         QTextStream stream( &f );
@@ -81,13 +102,13 @@ bool KSMoon::loadData() {
             fields = stream.readLine().split( ' ', QString::SkipEmptyParts );
 
             if ( fields.size() == 6 ) {
-                nd = fields[0].toInt();
-                nm = fields[1].toInt();
-                nm1= fields[2].toInt();
-                nf = fields[3].toInt();
-                Li = fields[4].toDouble();
-                Ri = fields[5].toDouble();
-                LRData.append(new MoonLRData(nd, nm, nm1, nf, Li, Ri));
+                LRData.append( MoonLRData() );
+                LRData.last().nd  = fields[0].toInt();
+                LRData.last().nm  = fields[1].toInt();
+                LRData.last().nm1 = fields[2].toInt();
+                LRData.last().nf  = fields[3].toInt();
+                LRData.last().Li  = fields[4].toDouble();
+                LRData.last().Ri  = fields[5].toDouble();
             }
         }
         f.close();
@@ -101,12 +122,12 @@ bool KSMoon::loadData() {
             fields = stream.readLine().split( ' ', QString::SkipEmptyParts );
             
             if ( fields.size() == 5 ) {
-                nd = fields[0].toInt();
-                nm = fields[1].toInt();
-                nm1= fields[2].toInt();
-                nf = fields[3].toInt();
-                Bi = fields[4].toDouble();
-                BData.append(new MoonBData(nd, nm, nm1, nf, Bi));
+                BData.append( MoonBData() );
+                BData.last().nd  = fields[0].toInt();
+                BData.last().nm  = fields[1].toInt();
+                BData.last().nm1 = fields[2].toInt();
+                BData.last().nf  = fields[3].toInt();
+                BData.last().Bi  = fields[4].toDouble();
             }
         }
         f.close();
@@ -121,11 +142,9 @@ bool KSMoon::findGeocentricPosition( const KSNumbers *num, const KSPlanetBase* )
     //by Jean Meeus (1991, Willmann-Bell, Inc. ISBN 0-943396-35-2.  http://www.willbell.com/math/mc1.htm)
     QString fname, snum, line;
     QFile f;
-    double DegtoRad;
-    double T, L, D, M, M1, F, E, A1, A2, A3;
-    double sumL, sumR, sumB;
 
-    DegtoRad = acos( -1.0 )/180.0;
+    double T, L, D, M, M1, F, A1, A2, A3;
+    double sumL, sumR, sumB;
 
     //Julian centuries since J2000
     T = num->julianCenturies();
@@ -133,43 +152,19 @@ bool KSMoon::findGeocentricPosition( const KSNumbers *num, const KSPlanetBase* )
     double Et = 1.0 - 0.002516*T - 0.0000074*T*T;
 
     //Moon's mean longitude
-    L = 218.3164591 + 481267.88134236*T - 0.0013268*T*T + T*T*T/538841.0 - T*T*T*T/65194000.0;
-    while ( L > 360.0 ) L -= 360.0;
-    while ( L < 0.0 ) L += 360.0;
-    L *= DegtoRad;
+    L = degToRad( 218.3164591 + 481267.88134236*T - 0.0013268*T*T + T*T*T/538841.0 - T*T*T*T/65194000.0 );
     //Moon's mean elongation
-    D = 297.8502042 + 445267.1115168*T - 0.0016300*T*T + T*T*T/545868.0 - T*T*T*T/113065000.0;
-    while ( D > 360.0 ) D -= 360.0;
-    while ( D < 0.0 ) D += 360.0;
-    D *= DegtoRad;
+    D = degToRad( 297.8502042 + 445267.1115168*T - 0.0016300*T*T + T*T*T/545868.0 - T*T*T*T/113065000.0 );
     //Sun's mean anomaly
-    M = 357.5291092 + 35999.0502909*T - 0.0001536*T*T + T*T*T/24490000.0;
-    while ( M > 360.0 ) M -= 360.0;
-    while ( M < 0.0 ) M += 360.0;
-    M *= DegtoRad;
+    M = degToRad( 357.5291092 + 35999.0502909*T - 0.0001536*T*T + T*T*T/24490000.0 );
     //Moon's mean anomaly
-    M1= 134.9634114 + 477198.8676313*T + 0.0089970*T*T + T*T*T/69699.0 - T*T*T*T/14712000.0;
-    while ( M1 > 360.0 ) M1 -= 360.0;
-    while ( M1 < 0.0 ) M1 += 360.0;
-    M1 *= DegtoRad;
+    M1= degToRad( 134.9634114 + 477198.8676313*T + 0.0089970*T*T + T*T*T/69699.0 - T*T*T*T/14712000.0 );
     //Moon's argument of latitude (angle from ascending node)
-    F = 93.2720993 + 483202.0175273*T - 0.0034029*T*T - T*T*T/3526000.0 + T*T*T*T/863310000.0;
-    while ( F > 360.0 ) F -= 360.0;
-    while ( F < 0.0 ) F += 360.0;
-    F *= DegtoRad;
+    F = degToRad( 93.2720993 + 483202.0175273*T - 0.0034029*T*T - T*T*T/3526000.0 + T*T*T*T/863310000.0 );
 
-    A1 = 119.75 +    131.849*T;
-    A2 =  53.09 + 479264.290*T;
-    A3 = 313.45 + 481226.484*T;
-    while ( A1 > 360.0 ) A1 -= 360.0;
-    while ( A1 < 0.0 ) A1 += 360.0;
-    while ( A2 > 360.0 ) A2 -= 360.0;
-    while ( A2 < 0.0 ) A2 += 360.0;
-    while ( A3 > 360.0 ) A3 -= 360.0;
-    while ( A3 < 0.0 ) A3 += 360.0;
-    A1 *= DegtoRad;
-    A2 *= DegtoRad;
-    A3 *= DegtoRad;
+    A1 = degToRad( 119.75 +    131.849*T );
+    A2 = degToRad(  53.09 + 479264.290*T );
+    A3 = degToRad( 313.45 + 481226.484*T );
 
     //Calculate the series expansions stored in moonLR.txt and moonB.txt.
     //
@@ -179,27 +174,27 @@ bool KSMoon::findGeocentricPosition( const KSNumbers *num, const KSPlanetBase* )
     if (!loadData()) return false;
 
     for ( int i=0; i < LRData.size(); ++i ) {
-        MoonLRData *mlrd = LRData[i];
+        const MoonLRData& mlrd = LRData[i];
 
-        E = 1.0;
-        if ( mlrd->nm ) { //if M != 0, include changing eccentricity of Earth's orbit
+        double E = 1.0;
+        if ( mlrd.nm ) { //if M != 0, include changing eccentricity of Earth's orbit
             E = Et;
-            if ( abs( mlrd->nm )==2 ) E = E*E; //use E^2
+            if ( abs( mlrd.nm )==2 ) E = E*E; //use E^2
         }
-        sumL += E*mlrd->Li*sin( mlrd->nd*D + mlrd->nm*M + mlrd->nm1*M1 + mlrd->nf*F );
-        sumR += E*mlrd->Ri*cos( mlrd->nd*D + mlrd->nm*M + mlrd->nm1*M1 + mlrd->nf*F );
+        sumL += E*mlrd.Li*sin( mlrd.nd*D + mlrd.nm*M + mlrd.nm1*M1 + mlrd.nf*F );
+        sumR += E*mlrd.Ri*cos( mlrd.nd*D + mlrd.nm*M + mlrd.nm1*M1 + mlrd.nf*F );
     }
 
     sumB = 0.0;
     for ( int i=0; i < BData.size(); ++i ) {
-        MoonBData *mbd = BData[i];
+        const MoonBData& mbd = BData[i];
 
-        E = 1.0;
-        if ( mbd->nm ) { //if M != 0, include changing eccentricity of Earth's orbit
+        double E = 1.0;
+        if ( mbd.nm ) { //if M != 0, include changing eccentricity of Earth's orbit
             E = Et;
-            if ( abs( mbd->nm )==2 ) E = E*E; //use E^2
+            if ( abs( mbd.nm )==2 ) E = E*E; //use E^2
         }
-        sumB += E*mbd->Bi*sin( mbd->nd*D + mbd->nm*M + mbd->nm1*M1 + mbd->nf*F );
+        sumB += E*mbd.Bi*sin( mbd.nd*D + mbd.nm*M + mbd.nm1*M1 + mbd.nf*F );
     }
 
     //Additive terms for sumL and sumB
@@ -207,8 +202,8 @@ bool KSMoon::findGeocentricPosition( const KSNumbers *num, const KSPlanetBase* )
     sumB += ( -2235.0*sin( L ) + 382.0*sin( A3 ) + 175.0*sin( A1-F ) + 175.0*sin( A1+F ) + 127.0*sin( L-M1 ) - 115.0*sin( L+M1 ) );
 
     //Geocentric coordinates
-    setEcLong( ( L + DegtoRad*sumL/1000000.0 ) * 180./dms::PI );  //convert radians to degrees
-    setEcLat( ( DegtoRad*sumB/1000000.0 ) * 180./dms::PI );
+    setEcLong( sumL/1000000.0 + L * 180.0 / dms::PI ); //convert radians to degrees
+    setEcLat(  sumB/1000000.0 );
     Rearth = ( 385000.56 + sumR/1000.0 )/AU_KM; //distance from Earth, in AU
 
     EclipticToEquatorial( num->obliquity() );
@@ -219,15 +214,28 @@ bool KSMoon::findGeocentricPosition( const KSNumbers *num, const KSPlanetBase* )
     return true;
 }
 
+void KSMoon::findMagnitude(const KSNumbers*)
+{
+    // This block of code to compute Moon magnitude (and the
+    // relevant data put into ksplanetbase.h) was taken from
+    // SkyChart v3 Beta
+    int p = floor( phase().Degrees() );
+    if( p > 180 )
+        p = p - 360;
+    int i = p / 10;
+    int k = p % 10;
+    int j = (i + 1 > 18) ? 18 : i + 1;
+    i = 18 - abs(i);
+    j = 18 - abs(j);
+    setMag( MagArray[i] + (MagArray[j] - MagArray[i]) * k / 10 );
+}
+
 void KSMoon::findPhase() {
     KSSun *Sun = (KSSun*)KStarsData::Instance()->skyComposite()->findByName( "Sun" );
     Phase = ecLong()->Degrees() - Sun->ecLong()->Degrees(); // Phase is obviously in degrees
     double DegPhase = dms( Phase ).reduce().Degrees();
-    int iPhase = int( 0.1*DegPhase+0.5 );
-    if (iPhase==36) iPhase = 0;
-    QString sPhase;
-    sPhase = sPhase.sprintf( "%02d", iPhase );
-    QString imName = "moon" + sPhase + ".png";
+    int iPhase = int( 0.1*DegPhase+0.5 ) % 36; // iPhase must be in [0,36) range
+    QString imName = QString().sprintf("moon%02d.png", iPhase);
 
     QFile imFile;
     if ( KSUtils::openDataFile( imFile, imName ) ) {
@@ -257,3 +265,8 @@ QString KSMoon::phaseName() const {
 
     else return i18n( "unknown" );
 }
+
+SkyObject::UID KSMoon::getUID() const
+{
+   return solarsysUID(UID_SOL_BIGOBJ) | 10;
+}
