@@ -1,7 +1,7 @@
 /***************************************************************************
  *   ktouchcolorscheme.h                                                   *
  *   -------------------                                                   *
- *   Copyright (C) 2003 by Andreas Nicolai                                 *
+ *   Copyright (C) 2003 by Andreas Nicolai <haavard@users.sourceforge.net> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,14 +12,10 @@
 #ifndef KTOUCHCOLORSCHEME_H
 #define KTOUCHCOLORSCHEME_H
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include <QColor>
+#include <QList>
 
-#include <qcolor.h>
-#include <qvaluevector.h>
-
-#include <kurl.h>
+class KUrl;
 
 class QDomDocument;
 class QDomElement;
@@ -68,14 +64,14 @@ class KTouchColorScheme {
     /// Loads several color maps (in XML format) from file (returns true if successful)
 	/// and _adds_ them to the current color maps. This function shall be called
 	/// directly after createDefaultColorSchemes().
-    static bool readList(QWidget * window, const KURL& url);
+    static bool readList(QWidget * window, const KUrl& url);
     /// Saves several color maps to file (returns true if successful).
 	/// Only non-default color maps are written to file.
-    static bool writeList(QWidget * window, const KURL& url);
+    static bool writeList(QWidget * window, const KUrl& url);
     /// Creates some default color schemes (erases m_colorSchemes before).
     static void createDefaults();
 	/// Contains all color schemes available in the program.
-	static QValueVector<KTouchColorScheme>	m_colorSchemes;
+	static QList<KTouchColorScheme>	m_colorSchemes;
 };
 
 #endif  // KTOUCHCOLORSCHEME_H
