@@ -5,8 +5,8 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2004-2007 Torsten Rahn <tackat@kde.org>"
-// Copyright 2007      Inge Wallin  <ingwa@kde.org>"
+// Copyright 2004-2007 Torsten Rahn <tackat@kde.org>
+// Copyright 2007      Inge Wallin  <ingwa@kde.org>
 //
 
 //
@@ -21,7 +21,8 @@ namespace Marble
 
 class MarbleWidget;
 
-class MarbleTest {
+class MarbleTest
+{
  public:
     explicit MarbleTest( MarbleWidget* marbleWidget );
     virtual ~MarbleTest(){ }
