@@ -5,13 +5,13 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2006-2007 Torsten Rahn <tackat@kde.org>"
-// Copyright 2007      Inge Wallin  <ingwa@kde.org>"
+// Copyright 2006-2007 Torsten Rahn <tackat@kde.org>
+// Copyright 2007      Inge Wallin  <ingwa@kde.org>
 //
 
 #include "QtMainWindow.h"
 
-#include <QtCore/QDebug>
+#include "MarbleDebug.h"
 #include <QtCore/QList>
 #include <QtCore/QSettings>
 #include <QtCore/QUrl>
@@ -24,6 +24,7 @@
 #include <QtGui/QIcon>
 #include <QtGui/QMenuBar>
 #include <QtGui/QStatusBar>
+#include <QtGui/QToolBar>
 #include <QtGui/QDesktopServices>
 #include <QtGui/QFileDialog>
 #include <QtGui/QMessageBox>
@@ -38,6 +39,7 @@
 
 #include <MarbleDirs.h>
 #include "lib/MarbleAboutDialog.h"
+#include "lib/QtMarbleConfigDialog.h"
 #include "lib/SunControlWidget.h"
 #include "lib/MarbleLocale.h"
 #include "AbstractDataPlugin.h"
@@ -46,7 +48,6 @@
 #include "MarbleMap.h"
 #include "MarbleModel.h"
 
-#include "QtMarbleConfigDialog.h"
 
 namespace
 {
@@ -60,7 +61,7 @@ MainWindow::MainWindow(const QString& marbleDataPath, QWidget *parent) : QMainWi
 {
     setUpdatesEnabled( false );
     
-    QString selectedPath = ( marbleDataPath.isEmpty() ) ? readMarbleDataPath() : marbleDataPath;
+    QString selectedPath = marbleDataPath.isEmpty() ? readMarbleDataPath() : marbleDataPath;
     if ( !selectedPath.isEmpty() )
         MarbleDirs::setMarbleDataPath( selectedPath );
 
@@ -71,7 +72,7 @@ MainWindow::MainWindow(const QString& marbleDataPath, QWidget *parent) : QMainWi
     setCentralWidget( m_controlView );
     
     // Initializing config dialog
-    m_configDialog = new QtMarbleConfigDialog( m_controlView, this );
+    m_configDialog = new QtMarbleConfigDialog( m_controlView->marbleWidget(), this );
     connect( m_configDialog, SIGNAL( settingsChanged() ),
 	     this, SLOT( updateSettings() ) );
     connect( m_configDialog, SIGNAL( clearVolatileCacheClicked() ),
@@ -106,7 +107,7 @@ void MainWindow::createActions()
      connect( m_openAct, SIGNAL( triggered() ),
               this, SLOT( openFile() ) );
 
-     m_downloadAct = new QAction( QIcon(":/icons/get-hot-new-stuff.png"), "Downloads...", this);
+     m_downloadAct = new QAction( QIcon(":/icons/get-hot-new-stuff.png"), tr("Download Maps..."), this);
      connect(m_downloadAct, SIGNAL(triggered()), this, SLOT(openMapSite()));
               
      m_exportMapAct = new QAction( QIcon(":/icons/document-save-as.png"), tr("&Export Map..."), this);
@@ -218,7 +219,8 @@ void MainWindow::createMenus()
 
     QList<RenderPlugin *> pluginList = m_controlView->marbleWidget()->renderPlugins();
     QList<RenderPlugin *>::const_iterator i = pluginList.constBegin();
-    for (; i != pluginList.constEnd(); ++i) {
+    QList<RenderPlugin *>::const_iterator const end = pluginList.constEnd();
+    for (; i != end; ++i ) {
         if ( (*i)->nameId() == "crosshairs" ) {
             m_fileMenu->addAction( (*i)->action() );
         }
@@ -255,6 +257,14 @@ void MainWindow::createMenus()
 
     connect( m_infoBoxesMenu, SIGNAL( aboutToShow() ), this, SLOT( createInfoBoxesMenu() ) ); 
     connect( m_onlineServicesMenu, SIGNAL( aboutToShow() ), this, SLOT( createOnlineServicesMenu() ) ); 
+
+//    FIXME: Discuss if this is the best place to put this
+    QList<RenderPlugin *>::const_iterator it = pluginList.constBegin();
+    QList<RenderPlugin *>::const_iterator const listEnd = pluginList.constEnd();
+    for (; it != listEnd; ++it ) {
+        connect( (*it), SIGNAL( actionGroupsChanged() ),
+                 this, SLOT( createPluginMenus() ) );
+    }
 }
 
 void MainWindow::createInfoBoxesMenu()
@@ -266,7 +276,8 @@ void MainWindow::createInfoBoxesMenu()
     QList<AbstractFloatItem *> floatItemList = m_controlView->marbleWidget()->floatItems();
 
     QList<AbstractFloatItem *>::const_iterator i = floatItemList.constBegin();
-    for (; i != floatItemList.constEnd(); ++i)
+    QList<AbstractFloatItem *>::const_iterator const end = floatItemList.constEnd();
+    for (; i != end; ++i )
     {
         m_infoBoxesMenu->addAction( (*i)->action() );
     }
@@ -278,8 +289,9 @@ void MainWindow::createOnlineServicesMenu()
     
     QList<RenderPlugin *> renderPluginList = m_controlView->marbleWidget()->renderPlugins();
     
-    QList<RenderPlugin *>::const_iterator i;
-    for( i = renderPluginList.constBegin(); i != renderPluginList.constEnd(); ++i ) {
+    QList<RenderPlugin *>::const_iterator i = renderPluginList.constBegin();
+    QList<RenderPlugin *>::const_iterator const end = renderPluginList.constEnd();
+    for (; i != end; ++i ) {
         // FIXME: This will go into the layer manager when AbstractDataPlugin is an interface
         AbstractDataPlugin *dataPlugin = qobject_cast<AbstractDataPlugin *>(*i);
         
@@ -289,6 +301,47 @@ void MainWindow::createOnlineServicesMenu()
     }
 }
 
+void MainWindow::createPluginMenus()
+{
+    //Remove and delete toolbars if they exist
+    while( !m_pluginToolbars.isEmpty() ) {
+        QToolBar* tb = m_pluginToolbars.takeFirst();
+        this->removeToolBar(tb);
+        delete tb;
+    }
+
+    //remove and delete old menus if they exist
+    while(  !m_pluginMenus.isEmpty() ) {
+        m_pluginMenus.takeFirst();
+//        FIXME: this does not provide an easy way to remove a menu.
+//        Make a workaround
+//        this->menuBar()->removeAction();
+    }
+
+    QList<QActionGroup*> *tmp_toolbarActionGroups;
+    QList<RenderPlugin *> renderPluginList = m_controlView->marbleWidget()->renderPlugins();
+    QList<RenderPlugin *>::const_iterator i = renderPluginList.constBegin();
+    QList<RenderPlugin *>::const_iterator const end = renderPluginList.constEnd();
+
+    //Load the toolbars
+    for (; i != end; ++i ) {
+        tmp_toolbarActionGroups = (*i)->toolbarActionGroups();
+
+        if ( tmp_toolbarActionGroups ) {
+            QToolBar* toolbar = new QToolBar(this);
+
+            foreach( QActionGroup* ag, *tmp_toolbarActionGroups ) {
+                toolbar->addActions( ag->actions() );
+            }
+
+            m_pluginToolbars.append( toolbar );
+            this->addToolBar( toolbar );
+        }
+    }
+
+//    FIXME: load the menus once the method has been settled on
+}
+
 void MainWindow::createStatusBar()
 {
     statusBar()->showMessage(tr("Ready"));
@@ -345,8 +398,8 @@ void MainWindow::printMapScreenShot()
 
         printSize.scale( ( printer.pageRect() ).size(), Qt::KeepAspectRatio );
 
-        QPoint printTopLeft( mapPageRect.x() + mapPageRect.width() /2  - printSize.width() /2 ,
-                             mapPageRect.y() + mapPageRect.height()/2  - printSize.height()/2 );
+        QPoint printTopLeft( mapPageRect.width() /2  - printSize.width() /2 ,
+                             mapPageRect.height()/2  - printSize.height()/2 );
 
         QRect mapPrintRect( printTopLeft, printSize );
 
@@ -435,8 +488,9 @@ void MainWindow::lockPosition( bool isChecked )
 {
     QList<AbstractFloatItem *> floatItemList = m_controlView->marbleWidget()->floatItems();
 
-    QList<AbstractFloatItem *>::const_iterator i;
-    for (i = floatItemList.constBegin(); i != floatItemList.constEnd(); ++i) 
+    QList<AbstractFloatItem *>::const_iterator i = floatItemList.constBegin();
+    QList<AbstractFloatItem *>::const_iterator const end = floatItemList.constEnd();
+    for (; i != end; ++i )
     {
         // Locking one would suffice as it affects all. 
 	// Nevertheless go through all.
@@ -475,7 +529,14 @@ void MainWindow::aboutMarble()
 
 void MainWindow::handbook()
 {
-    if( !QDesktopServices::openUrl( QUrl( "http://docs.kde.org/stable/en/kdeedu/marble/index.html" ) ) ) 
+    const QString code = MarbleLocale::languageCode();
+
+    QUrl handbookLocation( "http://docs.kde.org/stable/" + code + "/kdeedu/marble/index.html" );
+
+    if ( handbookLocation.isEmpty() )
+        handbookLocation = QUrl("http://docs.kde.org/stable/en/kdeedu/marble/index.html");
+
+    if( !QDesktopServices::openUrl( handbookLocation ) )
     qDebug() << "URL not opened";
 }
 
@@ -713,10 +774,6 @@ void MainWindow::updateSettings()
     m_controlView->marbleWidget()->setPersistentTileCacheLimit( m_configDialog->persistentTileCacheLimit() * 1024 );
     m_controlView->marbleWidget()->setVolatileTileCacheLimit( m_configDialog->volatileTileCacheLimit() * 1024 );
     
-    /*
-    m_controlView->marbleWidget()->setProxy( m_configDialog->proxyUrl(), m_configDialog->proxyPort(), m_configDialog->user(), m_configDialog->password() );
-    */
-
     m_controlView->marbleWidget()->updateChangedMap();
 }
 
