@@ -16,9 +16,13 @@
 
 #include "AbstractScanlineTextureMapper.h"
 
+namespace Marble
+{
 
 class EquirectScanlineTextureMapper : public AbstractScanlineTextureMapper
 {
+    Q_OBJECT
+
  public:
     explicit EquirectScanlineTextureMapper( TileLoader *tileLoader,
 					    QObject    *parent = 0 );
@@ -29,5 +33,6 @@ class EquirectScanlineTextureMapper : public AbstractScanlineTextureMapper
     int    m_oldYPaintedTop;
 };
 
+}
 
 #endif
