@@ -1,8 +1,8 @@
 /* This file is part of the KDE project
  *
- * Copyright 2004-2007 Torsten Rahn  <tackat@kde.org>"
- * Copyright 2007      Inge Wallin   <ingwa@kde.org>"
- * Copyright 2007      Thomas Zander <zander@kde.org>"
+ * Copyright 2004-2007 Torsten Rahn  <tackat@kde.org>
+ * Copyright 2007      Inge Wallin   <ingwa@kde.org>
+ * Copyright 2007      Thomas Zander <zander@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -28,13 +28,11 @@
 #include <QtCore/QByteArray>
 #include <QtCore/QDataStream>
 #include <QtCore/QtAlgorithms>
-#include <QtCore/QDebug>
 #include <QtCore/QTime>
 #include <QtCore/QTimer>
 #include <QtGui/QSortFilterProxyModel>
 #include <QtGui/QStandardItemModel>
 #include <QtGui/QTextFrame>
-#include <QtNetwork/QHttp>
 
 #include <global.h>
 
@@ -45,11 +43,17 @@
 #include <MarbleDirs.h>
 #include <FileViewModel.h>
 #include "gps/GpxFileModel.h"
-#include "PlaceMarkContainer.h"
+#include "gps/GpsLayer.h"
+#include "gps/PositionTracking.h"
+#include "MarbleLocale.h"
+#include "MarbleDebug.h"
 #include "MarblePlacemarkModel.h"
 #include "MarbleRunnerManager.h"
 #include "MathHelper.h"
 #include "MapThemeSortFilterProxyModel.h"
+#include "GeoSceneDocument.h"
+#include "GeoSceneHead.h"
+#include "Planet.h"
 
 #include "GeoOnfParser.h"
 #include "GeoDataDocument.h"
@@ -68,12 +72,12 @@ class MarbleControlBoxPrivate
     MarbleWidget  *m_widget;
     QString        m_searchTerm;
     bool           m_searchTriggered;
+    QStandardItemModel *m_celestialList;
 
     Ui::MarbleControlBox  uiWidget;
     QWidget              *m_navigationWidget;
     QWidget              *m_legendWidget;
     QWidget              *m_mapViewWidget;
-    QWidget              *m_currentLocationWidget;
     QWidget              *m_currentLocation2Widget;
     QWidget              *m_fileViewWidget;
 
@@ -82,6 +86,9 @@ class MarbleControlBoxPrivate
     MapThemeSortFilterProxyModel *m_mapSortProxy;
     
     MarbleRunnerManager  *m_runnerManager;
+    GeoSceneDocument      *mapTheme;
+
+    MarbleLocale* m_locale;
 };
 
 MarbleControlBoxPrivate::MarbleControlBoxPrivate()
@@ -98,8 +105,7 @@ MarbleControlBox::MarbleControlBox(QWidget *parent)
     d->m_widget = 0;
     d->m_searchTerm.clear();
     d->m_searchTriggered = false;
-
-    d->uiWidget.setupUi( this );
+    d->uiWidget.setupUi( this );    
 
     setFocusPolicy( Qt::NoFocus );
 //    setFocusProxy( d->uiWidget.searchLineEdit );
@@ -115,12 +121,9 @@ MarbleControlBox::MarbleControlBox(QWidget *parent)
     d->m_mapViewWidget = d->uiWidget.toolBox->currentWidget();
 
     d->uiWidget.toolBox->setCurrentIndex( 3 );
-    d->m_currentLocationWidget = d->uiWidget.toolBox->currentWidget();
-
-    d->uiWidget.toolBox->setCurrentIndex( 4 );
     d->m_fileViewWidget = d->uiWidget.toolBox->currentWidget();
 
-    d->uiWidget.toolBox->setCurrentIndex( 5 );
+    d->uiWidget.toolBox->setCurrentIndex( 4 );
     d->m_currentLocation2Widget = d->uiWidget.toolBox->currentWidget();
 
     d->m_sortproxy = new QSortFilterProxyModel( d->uiWidget.locationListView );
@@ -128,17 +131,13 @@ MarbleControlBox::MarbleControlBox(QWidget *parent)
 
     d->m_mapSortProxy = new MapThemeSortFilterProxyModel( this );
 
-//  d->m_currentLocationWidget->hide(); // Current location tab is hidden
-                                    //by default
- //   toolBox->removeItem( 3 );
     d->uiWidget.toolBox->setCurrentIndex(0);
 
-    //default
-    setCurrentLocationTabShown( false );
-    setCurrentLocation2TabShown( false );
-    setFileViewTabShown( false );
+    d->m_locale = MarbleGlobal::getInstance()->locale();
 
-    setupGpsOption();
+    //default
+    setCurrentLocationTabShown( true );
+    setFileViewTabShown( false );
 
     connect( d->uiWidget.goHomeButton,  SIGNAL( clicked() ),
              this,                      SIGNAL( goHome() ) );
@@ -161,11 +160,6 @@ MarbleControlBox::MarbleControlBox(QWidget *parent)
     connect( d->uiWidget.moveDownButton,  SIGNAL( clicked() ),
              this,                        SIGNAL (moveDown() ) );
 
-    connect( d->uiWidget.searchLineEdit,  SIGNAL( textChanged( const QString& ) ),
-             this,                        SLOT( searchLineChanged( const QString& ) ) );
-    connect( d->uiWidget.searchLineEdit,  SIGNAL( returnPressed() ),
-             this,                        SLOT( searchReturnPressed() ) );
-
     connect( d->uiWidget.locationListView, SIGNAL( centerOn( const QModelIndex& ) ),
              this,                         SLOT( mapCenterOnSignal( const QModelIndex& ) ) );
 
@@ -173,9 +167,8 @@ MarbleControlBox::MarbleControlBox(QWidget *parent)
 
     connect( d->uiWidget.marbleThemeSelectView, SIGNAL( selectMapTheme( const QString& ) ),
              this,                              SIGNAL( selectMapTheme( const QString& ) ) );
-    connect( d->uiWidget.projectionComboBox,    SIGNAL( currentIndexChanged( int ) ),
+    connect( d->uiWidget.projectionComboBox,    SIGNAL( activated( int ) ),
              this,                              SLOT( projectionSelected( int ) ) );
-
     connect( d->uiWidget.zoomSlider,  SIGNAL( sliderPressed() ),
              this,                      SLOT( adjustForAnimation() ) );
     connect( d->uiWidget.zoomSlider,  SIGNAL( sliderReleased() ),
@@ -184,26 +177,68 @@ MarbleControlBox::MarbleControlBox(QWidget *parent)
     d->uiWidget.projectionComboBox->setEnabled( true );
     
     d->m_runnerManager = new MarbleRunnerManager( this );
-    
+
     connect( d->m_runnerManager, SIGNAL( modelChanged(  MarblePlacemarkModel* ) ),
              this,               SLOT( setLocations( MarblePlacemarkModel* ) ) );    
+
+    connect( d->uiWidget.searchLineEdit,  SIGNAL( textChanged( const QString& ) ),
+             this,                        SLOT( searchLineChanged( const QString& ) ) );
+    connect( d->uiWidget.searchLineEdit,  SIGNAL( returnPressed() ),
+             this,                        SLOT( searchReturnPressed() ) );
+
+    // Setting up the celestial combobox
+    d->m_celestialList = new QStandardItemModel();
+    d->uiWidget.celestialBodyComboBox->setModel( d->m_celestialList );
+    connect( d->uiWidget.celestialBodyComboBox, SIGNAL( activated( const QString& ) ),
+             this,                              SLOT( selectCurrentMapTheme( const QString& ) ) );
 }
 
 MarbleControlBox::~MarbleControlBox()
 {
+    delete d->m_celestialList;
     delete d;
 }
 
-void MarbleControlBox::setMapThemeModel( QStandardItemModel *mapThemeModel ) {
+void MarbleControlBox::setMapThemeModel( QStandardItemModel *mapThemeModel )
+{
+    if ( mapThemeModel != d->m_mapThemeModel ) {
+        delete d->m_mapThemeModel;
+    }
+
     d->m_mapThemeModel = mapThemeModel;
     d->m_mapSortProxy->setSourceModel( d->m_mapThemeModel );
+    int currentIndex = d->uiWidget.celestialBodyComboBox->currentIndex();
+    QStandardItem * selectedItem = d->m_celestialList->item( currentIndex, 1 );
+
+    if ( selectedItem ) {
+        QString selectedId;
+        selectedId = selectedItem->text();
+        d->m_mapSortProxy->setFilterRegExp( QRegExp( selectedId, Qt::CaseInsensitive,QRegExp::FixedString ) );
+    }
+
     d->m_mapSortProxy->sort( 0 );
     d->uiWidget.marbleThemeSelectView->setModel( d->m_mapSortProxy );
     connect( d->m_mapThemeModel,       SIGNAL( rowsInserted( QModelIndex, int, int ) ),
-             this,                     SLOT( updateMapThemeView() ) );
-    updateMapThemeView();
+            this,                     SLOT( updateMapThemeView() ) );
 }
 
+void MarbleControlBox::updateCelestialModel()
+{
+    int row = d->m_mapThemeModel->rowCount();
+
+    for ( int i = 0; i < row; ++i )
+    {
+        QString celestialBodyId = ( d->m_mapThemeModel->data( d->m_mapThemeModel->index( i, 1 ) ).toString() ).section( '/', 0, 0 );
+        QString celestialBodyName = Planet::name( celestialBodyId );
+
+        QList<QStandardItem*> matchingItems = d->m_celestialList->findItems ( celestialBodyId, Qt::MatchExactly, 1 );
+        if ( matchingItems.isEmpty() ) {
+            d->m_celestialList->appendRow( QList<QStandardItem*>()
+                                << new QStandardItem( celestialBodyName )
+                                << new QStandardItem( celestialBodyId ) );
+        }
+    }   
+}
 
 void MarbleControlBox::updateButtons( int value )
 {
@@ -220,32 +255,22 @@ void MarbleControlBox::updateButtons( int value )
 }
 
 
-void MarbleControlBox::setupGpsOption()
-{
-    d->uiWidget.m_gpsDrawBox -> setEnabled( true );
-    d->uiWidget.m_gpsGoButton -> setEnabled( false );
-
-    d->uiWidget.m_latComboBox->setCurrentIndex( 0 );
-    d->uiWidget.m_lonComboBox->setCurrentIndex( 0 );
-
-    connect( d->uiWidget.m_gpsDrawBox, SIGNAL( clicked( bool ) ),
-             this,                     SLOT( disableGpsInput( bool ) ) );
-}
-
-
 void MarbleControlBox::addMarbleWidget(MarbleWidget *widget)
 {
     d->m_widget = widget;
 
-    // Make us aware of all the PlaceMarks in the MarbleModel so that
+    // Make us aware of all the Placemarks in the MarbleModel so that
     // we can search them.
-    setLocations( static_cast<MarblePlacemarkModel*>(d->m_widget->placeMarkModel()) );
-    d->uiWidget.locationListView->setSelectionModel( d->m_widget->placeMarkSelectionModel() );
+    setLocations( static_cast<MarblePlacemarkModel*>(d->m_widget->placemarkModel()) );
+
+//    FIXME: Why does this fail: "selection model works on a different model than the view..." ? 
+//    d->uiWidget.locationListView->setSelectionModel( d->m_widget->placemarkSelectionModel() );
 
-#ifndef KML_GSOC
     //set up everything for the FileModel
     d->uiWidget.m_fileView->setModel( widget->fileViewModel() );
-
+    delete d->uiWidget.m_fileView->selectionModel();
+    d->uiWidget.m_fileView->setSelectionModel(
+            widget->fileViewModel()->selectionModel());
     connect( d->uiWidget.m_fileView->selectionModel(),
 	     SIGNAL( selectionChanged( QItemSelection, QItemSelection )),
 	     this,
@@ -254,21 +279,6 @@ void MarbleControlBox::addMarbleWidget(MarbleWidget *widget)
              widget->fileViewModel(),    SLOT( saveFile() ) );
     connect( d->uiWidget.m_closeButton, SIGNAL( clicked() ) ,
              widget->fileViewModel(),    SLOT( closeFile() ) );
-#else
-    FileViewModel* model = widget->fileViewModel();
-    d->uiWidget.m_fileView->setModel( model );
-
-    connect( d->uiWidget.m_fileView->selectionModel(),
-             SIGNAL( selectionChanged( const QItemSelection&, const QItemSelection& )),
-             this,
-             SLOT( enableFileViewActions() ) );
-
-    connect( d->uiWidget.m_saveButton,  SIGNAL( clicked() ),
-             model,                     SLOT( saveFile() ) );
-
-    connect( d->uiWidget.m_closeButton, SIGNAL( clicked () ),
-             model,                     SLOT( closeFile() ) );
-#endif
 
     // Initialize the MarbleLegendBrowser
     d->uiWidget.marbleLegendBrowser->setMarbleWidget( d->m_widget );
@@ -290,16 +300,17 @@ void MarbleControlBox::addMarbleWidget(MarbleWidget *widget)
     connect( d->m_widget, SIGNAL( themeChanged( QString ) ),
              this,        SLOT( selectTheme( QString ) ) );
 
+
     connect( d->m_widget, SIGNAL( projectionChanged( Projection ) ),
              this,        SLOT( selectProjection( Projection ) ) );
     selectProjection( d->m_widget->projection() );
 
     connect( d->m_widget, SIGNAL( zoomChanged( int ) ),
-	    this,        SLOT( changeZoom( int ) ) );
+             this,        SLOT( changeZoom( int ) ) );
     connect( this,        SIGNAL( centerOn( const QModelIndex&, bool ) ),
-	    d->m_widget, SLOT( centerOn( const QModelIndex&, bool ) ) );
+             d->m_widget, SLOT( centerOn( const QModelIndex&, bool ) ) );
     connect( this,        SIGNAL( selectMapTheme( const QString& ) ),
-	    d->m_widget, SLOT( setMapThemeId( const QString& ) ) );
+             d->m_widget, SLOT( setMapThemeId( const QString& ) ) );
 
     // connect signals for the Legend
 
@@ -311,10 +322,11 @@ void MarbleControlBox::addMarbleWidget(MarbleWidget *widget)
              d->m_widget, SLOT( setShowGps( bool ) ) );
     connect( this, SIGNAL( gpsPositionChanged( qreal, qreal ) ),
              d->m_widget, SLOT( changeCurrentPosition( qreal, qreal ) ) );
-    connect( d->m_widget, SIGNAL( mouseClickGeoPosition( qreal, qreal,
-                                            GeoDataCoordinates::Unit ) ),
-             this, SLOT( receiveGpsCoordinates ( qreal, qreal,
-                                                 GeoDataCoordinates::Unit) ) );
+    connect( d->m_widget->model()->gpsLayer()->getPositionTracking(),
+             SIGNAL( gpsLocation( GeoDataCoordinates, qreal ) ),
+             this, SLOT( receiveGpsCoordinates( GeoDataCoordinates, qreal ) ) );
+    connect( d->uiWidget.navigationCheckBox, SIGNAL(clicked(bool) ),
+             d->m_widget->model()->gpsLayer(), SLOT( setVisible(bool) ) );
 
     connect( d->m_widget, SIGNAL( timeout() ),
              this,        SIGNAL( updateGps() ) );
@@ -352,6 +364,7 @@ void MarbleControlBox::setLocations(MarblePlacemarkModel* locations)
     t.start();
     d->m_sortproxy->setSourceModel( locations );
     d->m_sortproxy->setSortLocaleAware( true );
+    d->m_sortproxy->setDynamicSortFilter( false );
     d->m_sortproxy->sort( 0 );
     qDebug("MarbleControlBox (sort): Time elapsed: %d ms", t.elapsed());
 }
@@ -363,8 +376,13 @@ int MarbleControlBox::minimumZoom() const
 
 void MarbleControlBox::updateMapThemeView()
 {
-    if (d->m_widget)
-        selectTheme( d->m_widget->mapThemeId() );
+    updateCelestialModel();
+    
+    if ( d->m_widget ) {
+        QString mapThemeId = d->m_widget->mapThemeId();
+        if ( !mapThemeId.isEmpty() ) 
+            selectTheme( mapThemeId );
+    }
 }
 
 void MarbleControlBox::changeZoom(int zoom)
@@ -375,65 +393,48 @@ void MarbleControlBox::changeZoom(int zoom)
     d->uiWidget.zoomSlider->setMinimum( minimumZoom() );
 }
 
-void MarbleControlBox::disableGpsInput( bool in )
+
+void MarbleControlBox::receiveGpsCoordinates( GeoDataCoordinates in, qreal speed )
 {
-    d->uiWidget.m_latSpinBox->setEnabled( !in );
-    d->uiWidget.m_lonSpinBox->setEnabled( !in );
+    Q_UNUSED( speed );
+    if ( d->uiWidget.navigationCheckBox->isChecked() ) {
+        QString unitString;
+        QString speedString;
+        QString distanceUnitString;
+        QString distanceString;
+        qreal unitSpeed = 0.0;
+        qreal distance = 0.0;
 
-    d->uiWidget.m_latComboBox->setEnabled( !in );
-    d->uiWidget.m_lonComboBox->setEnabled( !in );
-
-    qreal t_lat = d->uiWidget.m_latSpinBox->value();
-    qreal t_lon = d->uiWidget.m_lonSpinBox->value();
-
-    if( d->uiWidget.m_lonComboBox->currentIndex() == 1 ){
-        t_lon *= -1;
-    }
-
-    if( d->uiWidget.m_latComboBox->currentIndex() == 1 ){
-        t_lat *= -1;
-    }
-
-    emit gpsPositionChanged( t_lon, t_lat );
-    emit gpsInputDisabled( in );
-}
-
-void MarbleControlBox::receiveGpsCoordinates( qreal x, qreal y,
-                                              GeoDataCoordinates::Unit unit)
-{
-    if ( d->uiWidget.m_catchGps->isChecked() ) {
-        switch(unit){
-        case GeoDataCoordinates::Degree:
-            d->uiWidget.m_lonSpinBox->setValue( y );
-            d->uiWidget.m_latSpinBox->setValue( x );
-            emit gpsPositionChanged( y, x );
+        switch ( d->m_locale->measureSystem() ) {
+            case Marble::Metric:
+            //kilometers per hour
+            unitString = tr("km/h");
+            unitSpeed = speed / 1000;
+            distanceUnitString = tr("m");
+            distance = in.altitude();
             break;
-        case GeoDataCoordinates::Radian:
-            qreal t_lat=0,t_lon=0;
-            t_lat = y * -RAD2DEG;
-            t_lon = x * +RAD2DEG;
 
-            if( t_lat < 0 ){
-                d->uiWidget.m_latSpinBox->setValue( -t_lat );
-                d->uiWidget.m_latComboBox->setCurrentIndex( 1 );
-            } else {
-                d->uiWidget.m_latSpinBox->setValue( t_lat );
-                d->uiWidget.m_latComboBox->setCurrentIndex( 0 );
-            }
-
-            if( t_lon < 0 ){
-                d->uiWidget.m_lonSpinBox->setValue( -t_lon );
-                d->uiWidget.m_lonComboBox->setCurrentIndex( 1 );
-            } else {
-                d->uiWidget.m_lonSpinBox->setValue( t_lon );
-                d->uiWidget.m_lonComboBox->setCurrentIndex( 0 );
-            }
-
-            emit gpsPositionChanged( t_lon, t_lat );
+            case Marble::Imperial:
+            //miles per hour
+            unitString = tr("m/h");
+            unitSpeed = (speed/1000) * KM2MI;
+            distanceUnitString = tr("ft");
+            distance = in.altitude() * M2FT;
+            break;
         }
+        // TODO read this value from the incoming signal
+        speedString = QLocale::system().toString( unitSpeed, 'f', 1);
+        distanceString = QString( "%1 %2" ).arg( distance, 0, 'f', 1, QChar(' ') ).arg( distanceUnitString );
+
+        d->uiWidget.speedLabel->setText( speedString.rightJustified(5) + ' ' + unitString );
+
+        d->uiWidget.longitudeValue->setText( in.lonToString() );
+        d->uiWidget.latitudeValue->setText( in.latToString() );
+        d->uiWidget.altitudeValue->setText( distanceString );
     }
 }
 
+
 void MarbleControlBox::enableFileViewActions()
 {
     bool tmp = d->uiWidget.m_fileView->selectionModel()
@@ -443,8 +444,8 @@ void MarbleControlBox::enableFileViewActions()
 
 #ifndef KML_GSOC
     if ( tmp ) {
-        QModelIndex tmpIndex = d->uiWidget.m_fileView ->
-                selectionModel() -> currentIndex();
+        QModelIndex tmpIndex =
+            d->uiWidget.m_fileView->selectionModel()->currentIndex();
         d->m_widget->gpxFileModel()->setSelectedIndex( tmpIndex );
     }
 #else
@@ -473,22 +474,16 @@ void MarbleControlBox::setMapViewTabShown( bool show )
     setWidgetTabShown( d->m_mapViewWidget, 2, show, title );
 }
 
-void MarbleControlBox::setCurrentLocationTabShown( bool show )
-{
-    QString  title = tr( "Current Location" );
-    setWidgetTabShown( d->m_currentLocationWidget, 3, show, title );
-}
-
 void MarbleControlBox::setFileViewTabShown( bool show )
 {
     QString  title = tr( "File View" );
-    setWidgetTabShown( d->m_fileViewWidget, 4, show, title );
+    setWidgetTabShown( d->m_fileViewWidget, 3, show, title );
 }
 
-void MarbleControlBox::setCurrentLocation2TabShown( bool show )
+void MarbleControlBox::setCurrentLocationTabShown( bool show )
 {
     QString  title = tr( "Current Location" );
-    setWidgetTabShown( d->m_currentLocation2Widget, 5, show, title );
+    setWidgetTabShown( d->m_currentLocation2Widget, 4, show, title );
 }
 
 
@@ -504,7 +499,7 @@ void MarbleControlBox::resizeEvent ( QResizeEvent * )
             setUpdatesEnabled(true);
         }
     } else {
-        if ( d->uiWidget.zoomSlider->isHidden() == true ) {
+        if ( d->uiWidget.zoomSlider->isHidden() ) {
             setUpdatesEnabled(false);
             d->uiWidget.zoomSlider->show();
             d->uiWidget.m_pSpacerFrame->setSizePolicy( QSizePolicy::Preferred,
@@ -519,7 +514,7 @@ void MarbleControlBox::searchLineChanged(const QString &search)
     d->m_searchTerm = search;
     // if search line is empty, restore original geonames
     if ( d->m_searchTerm.isEmpty() )
-        setLocations( static_cast<MarblePlacemarkModel*>( d->m_widget->placeMarkModel() ) );
+        setLocations( static_cast<MarblePlacemarkModel*>( d->m_widget->placemarkModel() ) );
     if ( d->m_searchTriggered )
         return;
     d->m_searchTriggered = true;
@@ -551,7 +546,6 @@ void MarbleControlBox::selectTheme( const QString &theme )
 {
     if ( !d->m_mapSortProxy || !d->m_widget )
         return;
-
     // Check if the new selected theme is different from the current one
     QModelIndex currentIndex = d->uiWidget.marbleThemeSelectView->currentIndex();
     QString indexTheme = d->m_mapSortProxy->data( d->m_mapSortProxy->index( 
@@ -560,6 +554,7 @@ void MarbleControlBox::selectTheme( const QString &theme )
 
     d->uiWidget.zoomSlider->setMaximum( d->m_widget->map()->maximumZoom() );
     updateButtons( d->uiWidget.zoomSlider->value() );
+
     if ( theme != indexTheme ) {
         /* indexTheme would be empty if the chosen map has not been set yet. As 
         this needs to be done after the mapThemeId has been set, check if that is 
@@ -570,13 +565,31 @@ void MarbleControlBox::selectTheme( const QString &theme )
         if( indexTheme.isEmpty() && !d->m_widget->mapThemeId().isEmpty() ) {
             QList<QStandardItem*> items = d->m_mapThemeModel->findItems( theme, Qt::MatchExactly, 1 );
             if( items.size() >= 1 ) {
-                QModelIndex iterIndex = items.at( 0 )->index();
+                QModelIndex iterIndex = items.first()->index();
                 QModelIndex iterIndexName = d->m_mapSortProxy->mapFromSource( iterIndex.sibling( iterIndex.row(), 0 ) );
-
+		
                 d->uiWidget.marbleThemeSelectView->setCurrentIndex( iterIndexName );
+
                 d->uiWidget.marbleThemeSelectView->scrollTo( iterIndexName );
             }
         }
+
+        QString selectedId = d->m_widget->mapTheme()->head()->target();
+        d->m_runnerManager->setCelestialBodyId( selectedId );
+        
+        QList<QStandardItem*> itemList = d->m_celestialList->findItems( selectedId, Qt::MatchExactly, 1 );
+
+        if ( !itemList.isEmpty() ) {
+            QStandardItem * selectedItem = itemList.first();
+
+            if ( selectedItem ) {
+                int selectedIndex = selectedItem->row();
+                d->uiWidget.celestialBodyComboBox->setCurrentIndex( selectedIndex );
+                d->m_mapSortProxy->setFilterRegExp( QRegExp( selectedId, Qt::CaseInsensitive,QRegExp::FixedString ) );
+            }
+
+            d->m_mapSortProxy->sort( 0 );
+        }
     }
 }
 
@@ -586,13 +599,41 @@ void MarbleControlBox::selectProjection( Projection projection )
         d->uiWidget.projectionComboBox->setCurrentIndex( (int) projection );
 }
 
+void MarbleControlBox::selectCurrentMapTheme( const QString& celestialBodyId )
+{
+    Q_UNUSED( celestialBodyId )
+
+    setMapThemeModel( d->m_mapThemeModel );
+
+    bool foundMapTheme = false;
+
+    QString currentMapThemeId = d->m_widget->mapThemeId();
+    
+    int row = d->m_mapSortProxy->rowCount();
+
+    for ( int i = 0; i < row; ++i )
+    {
+        QModelIndex index = d->m_mapSortProxy->index(i,1);
+        QString itMapThemeId = d->m_mapSortProxy->data(index).toString();
+        if ( currentMapThemeId == itMapThemeId )
+        {
+            foundMapTheme = true;
+            break;
+        }
+    }
+    if ( !foundMapTheme ) {
+        QModelIndex index = d->m_mapSortProxy->index(0,1);
+        d->m_widget->setMapThemeId( d->m_mapSortProxy->data(index).toString());
+    }
+
+    updateMapThemeView();
+}
 // Relay a signal and convert the parameter from an int to a Projection.
 void MarbleControlBox::projectionSelected( int projectionIndex )
 {
     emit projectionSelected( (Projection) projectionIndex );
 }
 
-
 void MarbleControlBox::mapCenterOnSignal( const QModelIndex &index )
 {
     emit centerOn( d->m_sortproxy->mapToSource( index ), true );
