@@ -5,13 +5,13 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2006-2007 Torsten Rahn <tackat@kde.org>"
-// Copyright 2007      Inge Wallin  <ingwa@kde.org>"
+// Copyright 2006-2007 Torsten Rahn <tackat@kde.org>
+// Copyright 2007      Inge Wallin  <ingwa@kde.org>
 //
 
 #include "MarbleThemeSelectView.h"
 
-#include <QtCore/QDebug>
+#include "MarbleDebug.h"
 #include <QtGui/QResizeEvent>
 
 using namespace Marble;
@@ -53,7 +53,7 @@ void MarbleThemeSelectView::selectedMapTheme( QModelIndex index )
     QModelIndex  colindex        = model->index( index.row(), 1, 
                                                  QModelIndex() );
     QString      currentmaptheme = (model->data( colindex )).toString();
-    qDebug() << currentmaptheme;
+    mDebug() << currentmaptheme;
     emit selectMapTheme( currentmaptheme ); 
 }
 
