@@ -5,8 +5,8 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2006-2007 Torsten Rahn <tackat@kde.org>"
-// Copyright 2007      Inge Wallin  <ingwa@kde.org>"
+// Copyright 2006-2007 Torsten Rahn <tackat@kde.org>
+// Copyright 2007      Inge Wallin  <ingwa@kde.org>
 //
 
 //
@@ -29,7 +29,6 @@ namespace Marble
 {
 
 class MarbleModel;
-class GeoDataCoordinates;
 class GeoPainter;
 class ViewportParams;
 
@@ -43,8 +42,12 @@ class MeasureTool : public QObject
     void  paint( GeoPainter *painter, ViewportParams *viewport,
                  bool antialiasing );
 
+ Q_SIGNALS:
+    void  numberOfMeasurePointsChanged( int newNumber );
+
  public Q_SLOTS:
     void  addMeasurePoint( qreal lon, qreal lat );
+    void  removeLastMeasurePoint();
     void  removeMeasurePoints();
 
  private:
