@@ -13,12 +13,12 @@
 #include "GeoDataFeature.h"
 #include "GeoDataFeature_p.h"
 
-#include <QtCore/QDebug>
 #include <QtCore/QDataStream>
 #include <QtCore/QSize>
 #include <QtGui/QPixmap>
 
 #include "MarbleDirs.h"
+#include "MarbleDebug.h"
 
 #include "GeoDataStyle.h"
 #include "GeoDataStyleMap.h"
@@ -27,9 +27,11 @@
 #include "GeoDataDocument.h"
 #include "GeoDataFolder.h"
 #include "GeoDataPlacemark.h"
+#include "GeoDataRegion.h"
 
 
-namespace Marble {
+namespace Marble
+{
 QFont GeoDataFeature::s_defaultFont = QFont("Sans Serif");
 
 bool GeoDataFeature::s_defaultStyleInitialized = false;
@@ -116,6 +118,11 @@ GeoDataFeature& GeoDataFeature::operator=( const GeoDataFeature& other )
     return *this;
 }
 
+QString GeoDataFeature::nodeType() const
+{
+    return p()->nodeType();
+}
+
 EnumFeatureId GeoDataFeature::featureId() const
 {
     return d->featureId();
@@ -402,6 +409,17 @@ void GeoDataFeature::setDescription( const QString &value)
     d->m_description = value;
 }
 
+bool GeoDataFeature::descriptionIsCDATA() const
+{
+    return d->m_descriptionCDATA;
+}
+
+void GeoDataFeature::setDescriptionCDATA( bool cdata )
+{
+    detach();
+    d->m_descriptionCDATA = cdata;
+}
+
 QString GeoDataFeature::styleUrl() const
 {
     return d->m_styleUrl;
@@ -440,7 +458,7 @@ GeoDataStyle* GeoDataFeature::style() const
         } else
         {
             // This should not happen
-            qDebug() << "No Style got assigned!";
+            mDebug() << "No Style got assigned!";
             return new GeoDataStyle( QPixmap(), 
               QFont( "Sans Serif",  8, 50, false ), QColor( Qt::black ) );
         }
@@ -453,6 +471,17 @@ void GeoDataFeature::setStyle( GeoDataStyle* style )
     d->m_style = style;
 }
 
+GeoDataRegion& GeoDataFeature::region() const
+{
+    return d->m_region;
+}
+
+void GeoDataFeature::setRegion( const GeoDataRegion& region )
+{
+    detach();
+    d->m_region = region;
+}
+
 GeoDataFeature::GeoDataVisualCategory GeoDataFeature::visualCategory() const
 {
     return d->m_visualCategory;
@@ -485,6 +514,16 @@ void GeoDataFeature::setStyleMap( GeoDataStyleMap* styleMap )
     d->m_styleMap = styleMap;
 }
 
+GeoDataLookAt* GeoDataFeature::lookAt() const
+{
+	return p()->m_lookAt;
+}
+
+void GeoDataFeature::setLookAt( GeoDataLookAt* lookAt )
+{
+	p()->m_lookAt = lookAt;
+}
+	
 int GeoDataFeature::popularityIndex() const
 {
     return d->m_popularityIndex;
