@@ -40,15 +40,11 @@ class GpsLayer : public AbstractLayer
 
     void changeCurrentPosition( qreal lat, qreal lon );
 
-    void loadGpx(const QString &fileName);
-    void addGpxFile( GpxFile* file );
 //  public slots:
     bool updateGps(const QSize &canvasSize, ViewParams *viewParams,
                    QRegion &reg);
 
-    QList<GpxFile*>     m_ownedGpxFiles;
-    QList<GpxFile*>     m_externalGpxFiles;
-//    GpxFileModel        *m_fileModel;
+    GpxFileModel        *m_fileModel;
     PositionTracking*   getPositionTracking();
 public slots:
     virtual void clearModel();
