@@ -5,15 +5,15 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2008 Torsten Rahn <tackat@kde.org>"
+// Copyright 2008 Torsten Rahn <tackat@kde.org>
 //
 
 #include "MapScaleFloatItem.h"
 
-#include <QtCore/QDebug>
 #include <QtCore/QRect>
 #include <QtGui/QPixmap>
 
+#include "MarbleDebug.h"
 #include "global.h"
 #include "MarbleLocale.h"
 #include "MarbleDataFacade.h"
@@ -85,37 +85,39 @@ bool MapScaleFloatItem::isInitialized () const
     return true;
 }
 
-bool MapScaleFloatItem::needsUpdate( ViewportParams *viewport )
+void MapScaleFloatItem::changeViewport( ViewportParams *viewport )
 {
     int viewportWidth = viewport->width();
 
     QString target = dataFacade()->target();
 
-    if (    m_radius == viewport->radius() && viewportWidth == m_viewportWidth 
-         && m_target == target && m_scaleInitDone )
+    if ( !(    m_radius == viewport->radius() 
+            && viewportWidth == m_viewportWidth
+            && m_target == target
+            && m_scaleInitDone ) )
     {
-        return false;
+        int fontHeight     = QFontMetrics( font() ).ascent();
+        setSize( QSizeF( viewport->width() / 2, 2 * padding() + fontHeight + 3 + m_scaleBarHeight ) );
+
+        m_leftBarMargin  = QFontMetrics( font() ).boundingRect( "0" ).width() / 2;
+        m_rightBarMargin = QFontMetrics( font() ).boundingRect( "0000" ).width() / 2;
+
+        m_scaleBarWidth = contentRect().width() - m_leftBarMargin - m_rightBarMargin;
+        m_viewportWidth = viewport->width();
+        m_radius = viewport->radius();
+        m_scaleInitDone = true;
+
+        update();
     }
-
-    int fontHeight     = QFontMetrics( font() ).ascent();
-    setSize( QSizeF( viewport->width() / 2, 2 * padding() + fontHeight + 3 + m_scaleBarHeight ) ); 
-
-    m_leftBarMargin  = QFontMetrics( font() ).boundingRect( "0" ).width() / 2;
-    m_rightBarMargin = QFontMetrics( font() ).boundingRect( "0000" ).width() / 2;
-
-    m_scaleBarWidth = contentRect().width() - m_leftBarMargin - m_rightBarMargin;
-    m_viewportWidth = viewport->width();
-    m_radius = viewport->radius();
-    m_scaleInitDone = true;
-
-    return true;
 }
 
-bool MapScaleFloatItem::renderFloatItem( GeoPainter *painter,
-					 ViewportParams *viewport,
-					 GeoSceneLayer * layer )
+void MapScaleFloatItem::paintContent( GeoPainter *painter,
+                                      ViewportParams *viewport,
+                                      const QString& renderPos,
+                                      GeoSceneLayer * layer )
 {
     Q_UNUSED( layer )
+    Q_UNUSED( renderPos )
 
     painter->save();
 
@@ -123,15 +125,13 @@ bool MapScaleFloatItem::renderFloatItem( GeoPainter *painter,
 
     int fontHeight     = QFontMetrics( font() ).ascent();
 
-    setSize( QSizeF( viewport->width() / 2, 2 * padding() + fontHeight + 3 + m_scaleBarHeight ) ); 
-
     m_scaleBarDistance = (qreal)(m_scaleBarWidth) * dataFacade()->planetRadius() / 
-                      (qreal)(viewport->radius());
+                         (qreal)(viewport->radius());
 
     Marble::DistanceUnit distanceUnit;
     distanceUnit = MarbleGlobal::getInstance()->locale()->distanceUnit();
 
-    if ( distanceUnit == Marble::Imperial ) {
+    if ( distanceUnit == Marble::MilesFeet ) {
         m_scaleBarDistance *= KM2MI;
     }
 
@@ -163,7 +163,7 @@ bool MapScaleFloatItem::renderFloatItem( GeoPainter *painter,
             Marble::DistanceUnit distanceUnit;
             distanceUnit = MarbleGlobal::getInstance()->locale()->distanceUnit();
 
-            if ( distanceUnit == Marble::Metric ) {
+            if ( distanceUnit == Marble::Meter ) {
                 if ( m_bestDivisor * m_valueInterval > 10000 ) {
                     m_unit = tr("km");
                     intervalStr.setNum( j * m_valueInterval / 1000 );
@@ -193,8 +193,6 @@ bool MapScaleFloatItem::renderFloatItem( GeoPainter *painter,
     }
 
     painter->restore();
-
-    return true;
 }
 
 void MapScaleFloatItem::calcScaleBar()
